@@ -1,26 +1,27 @@
-import pytzdata
-
+from typing import Tuple
 from typing import Union
 
+import pytzdata
+
 from .local_timezone import get_local_timezone
 from .local_timezone import set_local_timezone
 from .local_timezone import test_local_timezone
-
-from .timezone import Timezone as _Timezone
-from .timezone import FixedTimezone as _FixedTimezone
 from .timezone import UTC
+from .timezone import FixedTimezone as _FixedTimezone
+from .timezone import Timezone as _Timezone
+
 
 PRE_TRANSITION = "pre"
 POST_TRANSITION = "post"
 TRANSITION_ERROR = "error"
 
-timezones = pytzdata.timezones
+timezones = pytzdata.timezones  # type: Tuple[str, ...]
 
 
 _tz_cache = {}
 
 
-def timezone(name, extended=True):  # type: (Union[str, int]) -> _Timezone
+def timezone(name, extended=True):  # type: (Union[str, int], bool) -> _Timezone
     """
     Return a Timezone instance given its name.
     """
@@ -44,7 +45,7 @@ def fixed_timezone(offset):  # type: (int) -> _FixedTimezone
     Return a Timezone instance given its offset in seconds.
     """
     if offset in _tz_cache:
-        return _tz_cache[offset]
+        return _tz_cache[offset]  # type: ignore
 
     tz = _FixedTimezone(offset)
     _tz_cache[offset] = tz
